@@ -8,7 +8,7 @@
  *               editor with no support of digiKam database.
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,8 +29,6 @@
 
 #include <QDir>
 #include <QFile>
-#include <QSettings>
-#include <QTranslator>
 #include <QMessageBox>
 #include <QApplication>
 #include <QStandardPaths>
@@ -104,7 +102,7 @@ int main(int argc, char* argv[])
 
     QApplication app(argc, argv);
 
-    digikamSetDebugFilterRules();
+    digikamSetDebugFilterRules(system.enableLogging);
 
     tryInitDrMingw();
 
@@ -149,64 +147,11 @@ int main(int argc, char* argv[])
     QString iconTheme         = group.readEntry(QLatin1String("Icon Theme"), QString());
     QString colorTheme        = group.readEntry(QLatin1String("Theme"), QString::fromLatin1("Standard"));
 
-#if defined Q_OS_WIN || defined Q_OS_MACOS
+    // See bug #438701
 
-    bool loadTranslation = true;
+    installQtTranslationFiles(app);
 
-#else
-
-    bool loadTranslation = isRunningInAppImageBundle();
-
-#endif
-
-    QString transPath = QStandardPaths::locate(QStandardPaths::DataLocation,
-                                               QLatin1String("translations"),
-                                               QStandardPaths::LocateDirectory);
-
-    if (loadTranslation && !transPath.isEmpty())
-    {
-        QString klanguagePath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) +
-                                QLatin1Char('/') + QLatin1String("klanguageoverridesrc");
-
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Qt translations path:" << transPath;
-
-        QLocale locale;
-
-        if (!klanguagePath.isEmpty())
-        {
-            QSettings settings(klanguagePath, QSettings::IniFormat);
-            settings.beginGroup(QLatin1String("Language"));
-            QString language = settings.value(qApp->applicationName(), QString()).toString();
-            settings.endGroup();
-
-            if (!language.isEmpty())
-            {
-                locale = QLocale(language.split(QLatin1Char(':')).first());
-            }
-        }
-
-        QStringList qtCatalogs;
-        qtCatalogs << QLatin1String("qt");
-        qtCatalogs << QLatin1String("qtbase");
-        qtCatalogs << QLatin1String("qt_help");
-
-        foreach (const QString& catalog, qtCatalogs)
-        {
-            QTranslator* const translator = new QTranslator(&app);
-
-            if (translator->load(locale, catalog, QLatin1String("_"), transPath))
-            {
-                qCDebug(DIGIKAM_GENERAL_LOG) << "Loaded locale:" << locale.name()
-                                             << "from catalog:"  << catalog;
-
-                app.installTranslator(translator);
-            }
-            else
-            {
-                delete translator;
-            }
-        }
-    }
+    // ---
 
     MetaEngine::initializeExiv2();
 
@@ -243,24 +188,6 @@ int main(int argc, char* argv[])
         QIcon::setThemeName(iconTheme);
     }
 
-    // Workaround for the automatic icon theme color
-    // in KF-5.80/KF-5.88, depending on the color scheme.
-    // Note: In a Plasma environment, use the showFoto icon theme setting from the system.
-
-    if (
-        (colorTheme == QLatin1String("White Balance")) ||
-        (colorTheme == QLatin1String("Standard"))      ||
-        (colorTheme == QLatin1String("High Key"))      ||
-        (colorTheme == QLatin1String("Breeze"))
-       )
-    {
-        qApp->setPalette(QPalette(Qt::white));
-    }
-    else
-    {
-        qApp->setPalette(QPalette(Qt::darkGray));
-    }
-
 #ifdef Q_OS_WIN
 
     // Necessary to open native open with dialog on windows
